@@ -1,12 +1,12 @@
 """Python filesystem abstraction layer.
 """
 
-__import__("pkg_resources").declare_namespace(__name__)
+__import__("pkg_resources").declare_namespace(__name__)  # type: ignore
 
+from . import path
+from ._fscompat import fsdecode, fsencode
 from ._version import __version__
 from .enums import ResourceType, Seek
 from .opener import open_fs
-from ._fscompat import fsencode, fsdecode
-from . import path
 
 __all__ = ["__version__", "ResourceType", "Seek", "open_fs"]
