@@ -1,20 +1,20 @@
 from __future__ import unicode_literals
 
-import os
 import sys
+
+import os
+import pkg_resources
+import shutil
 import tempfile
 import unittest
-import pkg_resources
-
-import pytest
 
 from fs import open_fs, opener
-from fs.osfs import OSFS
-from fs.opener import registry, errors
-from fs.memoryfs import MemoryFS
 from fs.appfs import UserDataFS
+from fs.memoryfs import MemoryFS
+from fs.opener import errors, registry
 from fs.opener.parse import ParseResult
 from fs.opener.registry import Registry
+from fs.osfs import OSFS
 
 try:
     from unittest import mock
@@ -208,8 +208,13 @@ class TestManageFS(unittest.TestCase):
         self.assertTrue(mem_fs.isclosed())
 
 
-@pytest.mark.usefixtures("mock_appdir_directories")
 class TestOpeners(unittest.TestCase):
+    def setUp(self):
+        self.tmpdir = tempfile.mkdtemp()
+
+    def tearDown(self):
+        shutil.rmtree(self.tmpdir)
+
     def test_repr(self):
         # Check __repr__ works
         for entry_point in pkg_resources.iter_entry_points("fs.opener"):
@@ -260,7 +265,10 @@ class TestOpeners(unittest.TestCase):
         mem_fs_2 = opener.open_fs(mem_fs)
         self.assertEqual(mem_fs, mem_fs_2)
 
-    def test_open_userdata(self):
+    @mock.patch("appdirs.{}".format(UserDataFS.app_dir), autospec=True, spec_set=True)
+    def test_open_userdata(self, app_dir):
+        app_dir.return_value = self.tmpdir
+
         with self.assertRaises(errors.OpenerError):
             opener.open_fs("userdata://foo:bar:baz:egg")
 
@@ -269,13 +277,19 @@ class TestOpeners(unittest.TestCase):
         self.assertEqual(app_fs.app_dirs.appauthor, "willmcgugan")
         self.assertEqual(app_fs.app_dirs.version, "1.0")
 
-    def test_open_userdata_no_version(self):
+    @mock.patch("appdirs.{}".format(UserDataFS.app_dir), autospec=True, spec_set=True)
+    def test_open_userdata_no_version(self, app_dir):
+        app_dir.return_value = self.tmpdir
+
         app_fs = opener.open_fs("userdata://fstest:willmcgugan", create=True)
         self.assertEqual(app_fs.app_dirs.appname, "fstest")
         self.assertEqual(app_fs.app_dirs.appauthor, "willmcgugan")
         self.assertEqual(app_fs.app_dirs.version, None)
 
-    def test_user_data_opener(self):
+    @mock.patch("appdirs.{}".format(UserDataFS.app_dir), autospec=True, spec_set=True)
+    def test_user_data_opener(self, app_dir):
+        app_dir.return_value = self.tmpdir
+
         user_data_fs = open_fs("userdata://fstest:willmcgugan:1.0", create=True)
         self.assertIsInstance(user_data_fs, UserDataFS)
         user_data_fs.makedir("foo", recreate=True)
@@ -287,7 +301,26 @@ class TestOpeners(unittest.TestCase):
     def test_open_ftp(self, mock_FTPFS):
         open_fs("ftp://foo:bar@ftp.example.org")
         mock_FTPFS.assert_called_once_with(
-            "ftp.example.org", passwd="bar", port=21, user="foo", proxy=None, timeout=10
+            "ftp.example.org",
+            passwd="bar",
+            port=21,
+            user="foo",
+            proxy=None,
+            timeout=10,
+            tls=False,
+        )
+
+    @mock.patch("fs.ftpfs.FTPFS")
+    def test_open_ftps(self, mock_FTPFS):
+        open_fs("ftps://foo:bar@ftp.example.org")
+        mock_FTPFS.assert_called_once_with(
+            "ftp.example.org",
+            passwd="bar",
+            port=21,
+            user="foo",
+            proxy=None,
+            timeout=10,
+            tls=True,
         )
 
     @mock.patch("fs.ftpfs.FTPFS")
@@ -300,4 +333,5 @@ class TestOpeners(unittest.TestCase):
             user="foo",
             proxy="ftp.proxy.org",
             timeout=10,
+            tls=False,
         )
